<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Test Web App</title>
  </head>
  <body>
    <!-- These should pass -->
    <a href="/about">About Page</a>
    <a href="http://127.0.0.1:5000/contact">Contact Page</a>
    <a href="#">Hash Link</a>
    <a href="./rel">Rel Link</a>
    <a href="../rel2">Second Rel Link</a>

    <!-- These should fail -->
    <a href="/dhjaow">Failing Link</a>
    <a href="/login">Login Link</a>
    <a href="/500">500 Error</a>

    <!-- These have varied attributes to test LinkAnalysis -->
    <a href="/about/link-1" charset="utf-8">Link 1</a>
    <a href="/about/link-2" name="test">Link 2</a>
    <a href="/about/link-1" rev="test" coords="testing">Link 1 Repeat</a>

    <!-- Checks for `rel` attr on links with `target` attr -->
    <a href="/about/link-4" target="_blank">Link 4</a>
    <a href="/about/link-5" target="_blank" rel="noreferrer noopener">Link 5</a>
  </body>
</html>
